@@ -17,9 +17,7 @@ from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.payments.models import PaymentMethod
 from tinymce.widgets import TinyMCE
 from tendenci.core.perms.forms import TendenciBaseForm
-#from captcha.fields import CaptchaField
-#from simplemathcaptcha.fields import MathCaptchaField
-from tendenci.core.base.forms import SimpleMathField
+from captcha.fields import CaptchaField
 from tendenci.apps.user_groups.models import Group
 from tendenci.core.base.utils import get_template_list
 from tendenci.core.base.fields import EmailVerificationField
@@ -63,7 +61,12 @@ class FormForForm(forms.ModelForm):
                 field_class, field_widget = field.field_type, None
 
             if field.field_type == 'EmailVerificationField':
-                field_class = EmailVerificationField
+                one_email = get_setting('module', 'forms', 'one_email')
+                if one_email:
+                    field_class = forms.EmailField
+                else:
+                    field_class = EmailVerificationField
+
             elif field.field_type == 'CountryField' or field.field_type == 'StateProvinceField':
                 field_class = getattr(forms, 'ChoiceField')
             else:
@@ -146,7 +149,7 @@ class FormForForm(forms.ModelForm):
                 )
         
         if not self.user.is_authenticated() and get_setting('site', 'global', 'captcha'): # add captcha if not logged in
-            self.fields['captcha'] = SimpleMathField(label=_('Type the code below'))
+            self.fields['captcha'] = CaptchaField(label=_('Type the code below'))
 
 
     def clean_pricing_option(self):
